@@ -8,9 +8,9 @@
 #'
 #' @family Transformation methods
 #' @param mdata A mldr dataset used to train the binary models.
-#' @param base.method A string with the name of the base method. (Default:
-#'  \code{options("utiml.base.method", "SVM")})
-#' @param ... Others arguments passed to the base method for all subproblems
+#' @param base.algorithm A string with the name of the base algorithm (Default:
+#'  \code{options("utiml.base.algorithm", "SVM")})
+#' @param ... Others arguments passed to the base algorithm for all subproblems
 #' @param cores The number of cores to parallelize the training. Values higher
 #'  than 1 require the \pkg{parallel} package. (Default:
 #'  \code{options("utiml.cores", 1)})
@@ -32,18 +32,18 @@
 #' pred <- predict(model, toyml)
 #'
 #' \dontrun{
-#' # Use SVM as base method
+#' # Use SVM as base algorithm
 #' model <- br(toyml, "SVM")
 #' pred <- predict(model, toyml)
 #'
-#' # Change the base method and use 4 CORES
+#' # Change the base algorithm and use 4 CORES
 #' model <- br(toyml[1:50], 'RF', cores = 4, seed = 123)
 #'
 #' # Set a parameters for all subproblems
 #' model <- br(toyml, 'KNN', k=5)
 #' }
-br <- function(mdata, base.method = getOption("utiml.base.method", "SVM"), ...,
-               cores = getOption("utiml.cores", 1),
+br <- function(mdata, base.algorithm = getOption("utiml.base.algorithm", "SVM"),
+               ..., cores = getOption("utiml.cores", 1),
                seed = getOption("utiml.seed", NA)) {
   # Validations
   if (class(mdata) != "mldr") {
@@ -65,7 +65,7 @@ br <- function(mdata, base.method = getOption("utiml.base.method", "SVM"), ...,
     utiml_create_model(
       utiml_prepare_data(
         utiml_create_binary_data(mdata, label),
-        "mldBR", mdata$name, "br", base.method
+        "mldBR", mdata$name, "br", base.algorithm
       ), ...
     )
   }, cores, seed)
@@ -85,7 +85,7 @@ br <- function(mdata, base.method = getOption("utiml.base.method", "SVM"), ...,
 #'  matrix, data.frame or a mldr object.
 #' @param probability Logical indicating whether class probabilities should be
 #'  returned. (Default: \code{getOption("utiml.use.probs", TRUE)})
-#' @param ... Others arguments passed to the base method prediction for all
+#' @param ... Others arguments passed to the base algorithm prediction for all
 #'   subproblems.
 #' @param cores The number of cores to parallelize the training. Values higher
 #'  than 1 require the \pkg{parallel} package. (Default:
@@ -108,7 +108,7 @@ br <- function(mdata, base.method = getOption("utiml.base.method", "SVM"), ...,
 #' # Predict SVM bipartitions running in 4 cores
 #' pred <- predict(model, toyml, probability = FALSE, CORES = 4)
 #'
-#' # Passing a specif parameter for SVM predict method
+#' # Passing a specif parameter for SVM predict algorithm
 #' pred <- predict(model, dataset$test, na.action = na.fail)
 #' }
 predict.BRmodel <- function(object, newdata,
