@@ -10,12 +10,12 @@
 #'
 #' @family Transformation methods
 #' @param mdata A mldr dataset used to train the binary models.
-#' @param base.method A string with the name of the base method. (Default:
-#'  \code{options("utiml.base.method", "SVM")})
+#' @param base.algorithm A string with the name of the base algorithm. (Default:
+#'  \code{options("utiml.base.algorithm", "SVM")})
 #' @param chain A vector with the label names to define the chain order. If
 #'   empty the chain is the default label sequence of the dataset. (Default:
 #'   \code{NA})
-#' @param ... Others arguments passed to the base method for all subproblems.
+#' @param ... Others arguments passed to the base algorithm for all subproblems.
 #' @param cores The number of cores to parallelize the training. Values higher
 #'  than 1 require the \pkg{parallel} package. (Default:
 #'  \code{options("utiml.cores", 1)})
@@ -51,7 +51,7 @@
 #' #Run with multiple-cores
 #' model <- cc(toyml, 'RF', cores = 5, seed = 123)
 #' }
-cc <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
+cc <- function(mdata, base.algorithm = getOption("utiml.base.algorithm", "SVM"),
                chain = NA, ..., cores = getOption("utiml.cores", 1),
                seed = getOption("utiml.seed", NA)) {
   # Validations
@@ -82,7 +82,7 @@ cc <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
     utiml_create_model(
       utiml_prepare_data(
         cbind(basedata, labeldata[seq(lidx)]),
-        "mldCC", mdata$name, "cc", base.method, chain.order = lidx
+        "mldCC", mdata$name, "cc", base.algorithm, chain.order = lidx
       ), ...)
   }, cores, seed)
 
@@ -101,7 +101,7 @@ cc <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
 #'  matrix, data.frame or a mldr object.
 #' @param probability Logical indicating whether class probabilities should be
 #'  returned. (Default: \code{getOption("utiml.use.probs", TRUE)})
-#' @param ... Others arguments passed to the base method prediction for all
+#' @param ... Others arguments passed to the base algorithm prediction for all
 #'   subproblems.
 #' @param cores Ignored because this method does not support multi-core.
 #' @param seed An optional integer used to set the seed.
@@ -119,7 +119,7 @@ cc <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
 #' # Predict SVM bipartitions
 #' pred <- predict(model, toyml, prob = FALSE)
 #'
-#' # Passing a specif parameter for SVM predict method
+#' # Passing a specif parameter for SVM predict algorithm
 #' pred <- predict(model, toyml, na.action = na.fail)
 #' }
 predict.CCmodel <- function(object, newdata,
