@@ -8,13 +8,13 @@
 #'
 #' @family Transformation methods
 #' @param mdata A mldr dataset used to train the binary models.
-#' @param base.method A string with the name of the base method. (Default:
-#'  \code{options("utiml.base.method", "SVM")})
+#' @param base.algorithm A string with the name of the base algorithm. (Default:
+#'  \code{options("utiml.base.algorithm", "SVM")})
 #' @param estimate.models Logical value indicatind whether is necessary build
 #'  Binary Relevance classifier for estimate process. The default implementaion
 #'  use BR as estimators, however when other classifier is desirable then use
 #'  the value \code{FALSE} to skip this process. (Default: \code{TRUE}).
-#' @param ... Others arguments passed to the base method for all subproblems.
+#' @param ... Others arguments passed to the base algorithm for all subproblems.
 #' @param cores The number of cores to parallelize the training. Values higher
 #'  than 1 require the \pkg{parallel} package. (Default:
 #'  \code{options("utiml.cores", 1)})
@@ -40,10 +40,11 @@
 #' pred <- predict(model, toyml)
 #'
 #' \dontrun{
-#' # Use Random Forest as base method and 4 cores
+#' # Use Random Forest as base algorithm and 4 cores
 #' model <- dbr(toyml, 'RF', cores = 4)
 #' }
-dbr <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
+dbr <- function(mdata,
+                base.algorithm = getOption("utiml.base.algorithm", "SVM"),
                 estimate.models = TRUE, ...,
                 cores = getOption("utiml.cores", 1),
                 seed = getOption("utiml.seed", NA)) {
@@ -61,7 +62,8 @@ dbr <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
   # DBR Model class
   dbrmodel <- list(labels = rownames(mdata$labels), call = match.call())
   if (estimate.models) {
-    dbrmodel$estimation <- br(mdata, base.method, ..., cores=cores, seed=seed)
+    dbrmodel$estimation <- br(mdata, base.algorithm, ...,
+                              cores=cores, seed=seed)
   }
 
   # Create models
@@ -75,7 +77,7 @@ dbr <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
     utiml_create_model(
       utiml_prepare_data(
         utiml_create_binary_data(mdata, dbrmodel$labels[li], labeldata[-li]),
-        "mldDBR", mdata$name, "dbr", base.method
+        "mldDBR", mdata$name, "dbr", base.algorithm
       ), ...
     )
   }, cores, seed)
@@ -104,7 +106,7 @@ dbr <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
 #'  predictions.
 #' @param probability Logical indicating whether class probabilities should be
 #'  returned. (Default: \code{getOption("utiml.use.probs", TRUE)})
-#' @param ... Others arguments passed to the base method prediction for all
+#' @param ... Others arguments passed to the base algorithm prediction for all
 #'   subproblems.
 #' @param cores The number of cores to parallelize the training. Values higher
 #'  than 1 require the \pkg{parallel} package. (Default:
@@ -125,7 +127,7 @@ dbr <- function(mdata, base.method = getOption("utiml.base.method", "SVM"),
 #' model <- dbr(toyml)
 #' pred <- predict(model, toyml)
 #'
-#' # Passing a specif parameter for SVM predict method
+#' # Passing a specif parameter for SVM predict algorithm
 #' pred <- predict(model, toyml, na.action = na.fail)
 #'
 #' # Using other classifier (EBR) to made the labels estimatives
